package com.muyu.engine.remote;

import com.muyu.common.core.constant.ServiceNameConstants;
import com.muyu.common.core.domain.Result;
import com.muyu.engine.domain.RuleEngine;
import com.muyu.engine.remote.factory.RuleEngineManangerServiceFactory;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;

import java.util.List;

/**
 * RuleEngineManangerService
 *
 * @author LeYang
 * on 2024/5/9
 */
/**
 * 使用Feign创建的客户端注解，用于定义与服务提供者之间的通信配置。
 * 主要用于微服务架构中，通过声明式的方式定义远程服务调用。
 */
@FeignClient(
        //定义上下文ID，用于区分不同的Feign客户端实例。
        contextId = "RuleEngineManangerService",
        //指定要调用的服务的名称
        value = ServiceNameConstants.MUYU_RULE_ENGINE,
        //指定服务调用失败时的回退工厂
        fallbackFactory = RuleEngineManangerServiceFactory.class,
        // 指定服务访问的路径前缀。
        path = "/engine"
)
public interface RuleEngineManangerService {
    @PostMapping("/selectRuleEngine")
    public Result<List<RuleEngine>> selectRuleEngine();
}
